==> bitfront-library-7.2.2.tgz: package/src/app/shared/component/form/bit-dropdown-general.component.ts <==
import { OnInit, Input, ChangeDetectorRef, OnChanges, SimpleChange } from "@angular/core";
import { ActivatedRoute } from "@angular/router";

import { AyudaService } from "../../service/ayuda.service";
import { SessionSharedService } from "../../service/session-shared.service";
import { BitCustomComponent } from "./bit-custom.component";

/**
 * Clase que utiliza un custom componente para select de elementos
 * Utiliza la interfaz ControlValueAccessor
 *    <bit-select [domain]="'DOMAIN_TIPO_LOG'" id="tipolog" [control]="formControl">&nbsp;&nbsp;Tipus d'operació</bit-select>
 *
 * @input data: array de objetos a mostrar en el select. Puede ser null, en cuyo caso domain no puede ser null
 * @input domain: nombre del dominio que contiene los datos y que nos resolverá la página cuando cargue el componente. Puede ser null, en cuyo caso data no puede ser null
 * @input id: identificador del componente select
 * @input filter: true indicará que podemos buscar dentro del select, false que no.
 **/
export abstract class BitDropDownGeneralComponent extends BitCustomComponent implements OnInit, OnChanges {
  @Input() hideLabel: boolean = false; // forzar no reservar espacio para el nombre del campo
  @Input() data: any[]; // lista de valores estáticos con lo que inicializamos el select
  @Input() domain: string; // nombre del dominio del que queremos extraer los datos
  @Input() valorAs: string; // indica si hay que transformar el valor de entrada a un tipo de dato (p. ej., "string", "number")

  listaOpciones: any[] = [];
  listaOpcionesVisible: any[] = [];

  constructor(
    protected router: ActivatedRoute,
    protected sessionShared: SessionSharedService,
    protected ayudaService: AyudaService,
    protected changeDetectorRef: ChangeDetectorRef
  ) {
    super(ayudaService, changeDetectorRef);
  }

  ngOnInit() {
    super.ngOnInit();
    if (this.data == null && this.domain != null) {
      //esta manera retornaría los datos alojados en el snapshot pero no tendríamos refresco en el caso de producirse
      //this.tiposLog = this.getTiposLogFromDomain(this.route.snapshot.data[TipoLog.DOMAIN_TIPO_LOG]);//this.route.data.pluck(TipoLog.DOMAIN_TIPO_LOG);
      //esta manera nos permite subscribirnos a los datos de data con lo que si hay refresco nos enteramos
      this.router.data.subscribe(result => {
        let dominios = result["dominios"];
        let domainTipo = dominios[this.domain];
        if (domainTipo != null) {
          domainTipo.subscribe(
            result => {
              //console.log(result);
              this.sessionShared.set(this.domain, result.slice()); // almacenamos en sesión una copia para evitar transmitir cambios
              this.listaOpciones = result.slice();
              this.postRetrieveData();
            },
            error => {
              this.listaOpciones = [{ value: null, label: "Error carrega dominis" }];
            }
          );
        } else {
          console.log("No hay datos para el dominio", this.domain);
          this.listaOpciones = [{ value: null, label: "Error carrega dominis" }];
        }
      });
    } else if (this.data) {
      // incluso si la lista de valores ha sido proporcionada,
      // hay que añadir algunos comportamientos posteriores
      this.listaOpciones = this.data.slice();
      this.postRetrieveData();
    }
    //console.log("Componente inicializado");
  }

  ngOnChanges(changes: { [propKey: string]: SimpleChange }) {
    // console.log('BitDropDownGeneralComponent OnChanges', changes);
    for (let propName in changes) {
      let changedProp = changes[propName];
      if (propName === "control") {
        if (this.control.value) {
          if (this.valorAs === "string" && typeof this.control.value !== "string") { this.control.setValue("" + this.control.value); }
          else if (this.valorAs === "number" && typeof this.control.value !== "number") { this.control.setValue(+this.control.value); }
        }
      }
    }
  }

  abstract postRetrieveData();

  onBlur() {
    this.onTouchedCallback();
  }

  onFocus() {
    this.onTouchedCallback();
  }
}

==> bitfront-library-11.0.0.tgz: package/src/app/shared/component/form/bit-dropdown-general.component.ts <==
import { OnInit, Input, ChangeDetectorRef, Directive } from "@angular/core";
import { ActivatedRoute } from "@angular/router";

import { AyudaService } from "../../service/ayuda.service";
import { SessionSharedService } from "../../service/session-shared.service";
import { BitCustomComponent } from "./bit-custom.component";

/**
 * Clase que utiliza un custom componente para select de elementos
 * Utiliza la interfaz ControlValueAccessor
 *    <bit-select [domain]="'DOMAIN_TIPO_LOG'" id="tipolog" [control]="formControl">&nbsp;&nbsp;Tipus d'operació</bit-select>
 *
 * @input data: array de objetos a mostrar en el select. Puede ser null, en cuyo caso domain no puede ser null
 * @input domain: nombre del dominio que contiene los datos y que nos resolverá la página cuando cargue el componente. Puede ser null, en cuyo caso data no puede ser null
 * @input id: identificador del componente select
 * @input filter: true indicará que podemos buscar dentro del select, false que no.
 **/
@Directive()
export abstract class BitDropDownGeneralComponent extends BitCustomComponent implements OnInit {
  @Input() hideLabel: boolean = false; // forzar no reservar espacio para el nombre del campo
  @Input() data: any[]; // lista de valores estáticos con lo que inicializamos el select
  @Input() domain: string; // nombre del dominio del que queremos extraer los datos
  @Input() valueAs: string; // indica si hay que transformar el valor de entrada a un tipo de dato: "string", "number"
  @Input() id: any;

  listaOpciones: any[] = [];
  listaOpcionesVisible: any[] = [];
  valorActual: any; // solo se usa para hacer la transformación cuando es estrictamente necesario

  constructor(
    protected router: ActivatedRoute,
    protected sessionShared: SessionSharedService,
    protected ayudaService: AyudaService,
    protected changeDetectorRef: ChangeDetectorRef
  ) {
    super(ayudaService, changeDetectorRef);
  }

  /** Si se dan las condiciones, transforma los valores de number a string (o viceversa). */
  protected transformValue() {
    if (this.control.value !== this.valorActual) {
      if (!this.control.value || this.control.value.length === 0) {
        this.valorActual = this.control.value;
      }
      // si es necesario, realizamos la transformación y aplicamos el nuevo valor
      else if (this.valueAs === "string" && typeof this.control.value[0] !== "string") {
        this.valorActual = this.control.value.map(String);
        this.control.setValue(this.valorActual, { emitEvent: false });
      } else if (this.valueAs === "number" && typeof this.control.value[0] !== "number") {
        this.valorActual = this.control.value.map(Number);
        this.control.setValue(this.valorActual, { emitEvent: false });
      }
    }
  }

  ngOnInit() {
    super.ngOnInit();
    if (this.data == null && this.domain != null) {
      //esta manera retornaría los datos alojados en el snapshot pero no tendríamos refresco en el caso de producirse
      //this.tiposLog = this.getTiposLogFromDomain(this.route.snapshot.data[TipoLog.DOMAIN_TIPO_LOG]);//this.route.data.pluck(TipoLog.DOMAIN_TIPO_LOG);
      //esta manera nos permite subscribirnos a los datos de data con lo que si hay refresco nos enteramos
      this.router.data.subscribe(result => {
        let dominios = result["dominios"];
        let domainTipo = dominios[this.domain];
        if (domainTipo != null) {
          domainTipo.subscribe(
            result => {
              //console.log(result);
              this.sessionShared.set(this.domain, result.slice()); // almacenamos en sesión una copia para evitar transmitir cambios
              this.listaOpciones = result.slice();
              this.postRetrieveData();
            },
            error => {
              this.listaOpciones = [{ value: null, label: "Error carrega dominis" }];
            }
          );
        } else {
          console.log("No hay datos para el dominio", this.domain);
          this.listaOpciones = [{ value: null, label: "Error carrega dominis" }];
        }
      });
    } else if (this.data) {
      // incluso si la lista de valores ha sido proporcionada,
      // hay que añadir algunos comportamientos posteriores
      this.listaOpciones = this.data.slice();
      this.postRetrieveData();
    }
    //console.log("Componente inicializado");
  }

  abstract postRetrieveData();

  onBlur() {
    this.onTouchedCallback();
  }

  onFocus() {
    this.onTouchedCallback();
  }
}
